//! Data Types and functions related to rendering.

pub use camera::Camera;
pub use material::{Diffuse, Emissive, Material, Metallic, Refractive};
pub use render_engine::RenderEngine;
pub use scene::Scene;

mod camera;
mod material;
mod render_engine;
mod scene;
